==> fonts-sil-doulos_6.001.orig.tar.xz: DoulosSIL-6.001/documentation/source/charset.md <==
---
title: Doulos SIL - Character Set Support
fontversion: 6.001
---

This font supports over 2,300 characters from [The Unicode Standard](https://unicode.org/) as well as a number of [Private Use Area (PUA)](https://scripts.sil.org/SILPUAassignments) characters. In total, over 3,500 glyphs are included, supporting stylistic alternates for a number of characters as well as a large number of ligated sequences (e.g., contour tone letters used in phonetic transcription of tonal languages). 

## Supported characters

The following character ranges are supported by this font:

Unicode block | Doulos SIL support
------------- | ---------------
C0 Controls and Basic Latin|U+0020..U+007E
C1 Controls and Latin-1 Supplement|U+00A0..U+00FF
Latin Extended-A|U+0100..U+0148, U+014A..U+017F
Latin Extended-B|U+0180..U+024F
IPA Extensions|U+0250..U+02AF
Spacing Modifier Letters|U+02B0..U+02FF
Combining Diacritical Marks|U+0300..U+0320, U+0323..U+033F, U+0346..U+036F
Greek and Coptic|U+0387, U+0393..U+0394, U+0398, U+039E, U+03A0, U+03A8..U+03A9, U+03B1..U+03B4, U+03B8, U+03BB..U+03BC, U+03C0..U+03C1, U+03C3, U+03C6..U+03C7, U+03C9, U+03D1, U+03F4
Cyrillic|U+0400..U+045F, U+0462..U+0463, U+0472..U+0475, U+048A..U+04FF
Cyrillic Supplementary|U+0500..U+052F
Combining Diacritical Marks Extended|U+1AB0..U+1ABA
Phonetic Extensions|U+1D00..U+1D7F
Phonetic Extensions Supplement|U+1D80..U+1DBF
Combining Diacritical Marks Supplement|U+1DC2, U+1DC4..U+1DCD, U+1DF5, U+1DFD..U+1DFF
Latin Extended Additional|U+1E00..U+1EFF
General Punctuation|U+2000..U+2030, U+2032..U+203B, U+203C, U+203F.. U+2041, U+2044, U+2053, U+2057, U+2060..U+2063, U+206A..U+206F
Superscripts and Subscripts|U+2070..U+2071, U+2074..U+208E, U+2090..U+209C
Currency Symbols|U+20A0..U+20BF
Combining Diacritical Marks for Symbols|U+20E5, U+20EC..U+20EF
Letterlike Symbols|U+210C, U+2113, U+2116..U+2117, U+211F, U+2122..U+2123, U+2126, U+212D, U+2135, U+214F
Number Forms|U+2150..U+2189
Arrows|U+2190..U+219B, U+21A8, U+21D0..U+21D5
Mathematical Operators|U+2202..U+2206, U+220F, U+2211..U+2213, U+2219..U+221A, U+221E, U+2225..U+2226, U+222B, U+2234..U+2235, U+223C, U+2248, U+225F, U+2260..U+2262, U+2264..U+2265, U+U+2282..U+2287
Miscellaneous Technical|U+2308..U+230B, U+231C..U+231F, U+2329..U+232A, U+239B..U+23AD
Control Pictures|U+2423
Geometric Shapes|U+25CA, U+25CC
Miscellaneous Symbols|U+2640, U+2642, U+266D, U+266F
Dingbats|U+2713, U+274D
Misc. Math. Symbols-A|U+27E6..U+27E9
Latin Extended-C|U+2C60..U+2C7F
Coptic|U+2C88
Supplemental Punctuation|U+2E00..U+2E0D, U+2E13, U+2E14, U+2E17, U+2E22..U+2E25, U+2E3A..U+2E3B
Modifier Tone Letters|U+A700..U+A71F
Latin Extended-D|U+A720..U+A78F, U+A790..U+A799, U+A7A0..U+A7AF, U+A7B0..U+A7B9, U+A7F7..U+A7FF
Kayah Li|U+A92E
Latin Extended-E|U+AB30, U+AB53, U+AB5C, U+AB5E, U+AB64..U+AB65
PUA: Specials|U+F130..U+F133
PUA: Modifier letters (e.g. superscripts)|U+F1A1, U+F1A3..U+F1A4, U+F1AB, U+F1AE, U+F1B4..U+F1B5, U+F1BC, U+F1CD..U+F1CE, U+F1F1..U+F1F9
PUA: Latin|U+F20D, U+F234..U+F235, U+F258..U+F259, U+F267..U+F269, U+F26C..U+F26D
PUA: Cyrillic|U+F326..U+F327
Alphabetic Presentation Forms|U+FB00..U+FB04
Variation Selectors|U+FE00..U+FE0F
Combining Half Marks|U+FE20..U+FE23
Arabic Presentation Forms-B|U+FEFF (zero-width no-break space)
Specials|U+FFF9..U+FFFD
Mathematical Alphanumeric Symbols|U+1D40C, U+1D504..U+1D505, U+1D50A, U+1D50E..U+1D510, U+1D513..U+1D514, U+1D516..U+1D517, U+1D519

## Private-use (PUA) characters

There are a number of private-use characters that are supported in this font. These conform to [SIL International’s corporate registry](http://scripts.sil.org/PUA_home) for usage of the Unicode private-use areas. Characters which are not yet in Unicode are shown below. 

### Specials

- U+F130  FONT BASELINE AND SIDE-BEARING MARKER LEFT
- U+F131  FONT BASELINE AND SIDE-BEARING MARKER RIGHT
- U+F132  FONT VERTICAL METRICS MARKER LEFT
- U+F133  FONT VERTICAL METRICS MARKER RIGHT

### Modifier Letters

- U+F1A1  MODIFIER LETTER SMALL AE
- U+F1A3  MODIFIER LETTER SMALL REVERSED E
- U+F1A4  MODIFIER LETTER SMALL CLOSED REVERSED OPEN E
- U+F1AB  MODIFIER LETTER SMALL O WITH STROKE
- U+F1AE  MODIFIER LETTER SMALL CAPITAL OE
- U+F1B4  MODIFIER LETTER SMALL CAPITAL Y
- U+F1B5  MODIFIER LETTER SMALL RAMS HORN
- U+F1BC  MODIFIER LETTER SMALL H WITH STROKE
- U+F1CD  MODIFIER LETTER SMALL CAPITAL U BAR
- U+F1CE  MODIFIER LETTER SMALL TURNED Y

### Latin

- U+F20D  LATIN CAPITAL LETTER D WITH STROKE AND HOOK
- U+F234  LATIN CAPITAL LETTER Z WITH PALATAL HOOK
- U+F235  LATIN SMALL LETTER EZH WITH PALATAL HOOK
- U+F258  LATIN LETTER SMALL CAPITAL I OVER SMALL SCHWA
- U+F259  LATIN LETTER SMALL UPSILON OVER SMALL SCHWA
- U+F267  LATIN SMALL LETTER TURNED Y WITH BELT
- U+F268  LATIN LETTER SMALL CAPITAL L WITH BELT
- U+F269  LATIN SMALL LETTER TURNED R WITH LONG LEG AND HOOK
- U+F26D  LATIN SMALL LETTER B WITH LEFT HOOK
- U+F26E  LATIN CAPITAL LETTER RAMS HORN

### Cyrillic

- U+F326  CYRILLIC CAPITAL LETTER GHE WITH STROKE AND DESCENDER
- U+F327  CYRILLIC SMALL LETTER GHE WITH STROKE AND DESCENDER

### Deprecated SIL Corporate PUA characters

Some characters formerly in the PUA have been added to Unicode, and so have been deprecated in our fonts. Those PUA characters are displayed as black boxes containing a white image of the deprecated glyph.

==> fonts-sil-doulos_6.101.orig.tar.xz: DoulosSIL-6.101/documentation/source/charset.md <==
---
title: Doulos SIL - Character Set Support
fontversion: 6.101
---

This font supports over 2,300 characters from [The Unicode Standard](https://unicode.org/) as well as a number of [Private Use Area (PUA)](https://scripts.sil.org/SILPUAassignments) characters. In total, over 3,500 glyphs are included, supporting stylistic alternates for a number of characters as well as a large number of ligated sequences (e.g., contour tone letters used in phonetic transcription of tonal languages). 

## Supported characters

The following character ranges are supported by this font:

Unicode block | Doulos SIL support
------------- | ---------------
C0 Controls and Basic Latin|U+0020..U+007E
C1 Controls and Latin-1 Supplement|U+00A0..U+00FF
Latin Extended-A|U+0100..U+0148, U+014A..U+017F
Latin Extended-B|U+0180..U+024F
IPA Extensions|U+0250..U+02AF
Spacing Modifier Letters|U+02B0..U+02FF
Combining Diacritical Marks|U+0300..U+0320, U+0323..U+033F, U+0346..U+036F
Greek and Coptic|U+0387, U+0393..U+0394, U+0398, U+039E, U+03A0, U+03A8..U+03A9, U+03B1..U+03B4, U+03B8, U+03BB..U+03BC, U+03C0..U+03C1, U+03C3, U+03C6..U+03C7, U+03C9, U+03D1, U+03F4
Cyrillic|U+0400..U+045F, U+0462..U+0463, U+0472..U+0475, U+048A..U+04FF
Cyrillic Supplementary|U+0500..U+052F
Combining Diacritical Marks Extended|U+1AB0..U+1ABA
Phonetic Extensions|U+1D00..U+1D7F
Phonetic Extensions Supplement|U+1D80..U+1DBF
Combining Diacritical Marks Supplement|U+1DC2, U+1DC4..U+1DCD, U+1DF5, U+1DFD..U+1DFF
Latin Extended Additional|U+1E00..U+1EFF
General Punctuation|U+2000..U+2041, U+2044, U+204A, U+2053, U+2057, U+2060..U+2063, U+206A..U+206F
Superscripts and Subscripts|U+2070..U+2071, U+2074..U+208E, U+2090..U+209C
Currency Symbols|U+20A0..U+20C0
Combining Diacritical Marks for Symbols|U+20E5, U+20EC..U+20EF
Letterlike Symbols|U+210C, U+2113, U+2116..U+2117, U+211F, U+2122..U+2123, U+2126, U+212D, U+2135, U+214F
Number Forms|U+2150..U+2189
Arrows|U+2190..U+219B, U+21A8, U+21D0..U+21D5
Mathematical Operators|U+2202..U+2206, U+220F, U+2211..U+2213, U+2219..U+221A, U+221E, U+2225..U+2226, U+222B, U+2234..U+2235, U+223C, U+2248, U+225F, U+2260..U+2262, U+2264..U+2265, U+U+2282..U+2287
Miscellaneous Technical|U+2308..U+230B, U+231C..U+231F, U+2329..U+232A, U+239B..U+23AD
Control Pictures|U+2423
Geometric Shapes|U+25CA, U+25CC
Miscellaneous Symbols|U+2640, U+2642, U+266D, U+266F
Dingbats|U+2713, U+274D
Misc. Math. Symbols-A|U+27E6..U+27E9
Latin Extended-C|U+2C60..U+2C7F
Coptic|U+2C88
Supplemental Punctuation|U+2E00..U+2E0D, U+2E13, U+2E14, U+2E17, U+2E22..U+2E25, U+2E3A..U+2E3B, U+2E3E
Modifier Tone Letters|U+A700..U+A71F
Latin Extended-D|U+A720..U+A78F, U+A790..U+A799, U+A7A0..U+A7AF, U+A7B0..U+A7B9, U+A7C4..U+A7C6, U+A7F7..U+A7FF
Kayah Li|U+A92E
Latin Extended-E|U+AB30, U+AB53, U+AB5C, U+AB5E, U+AB64..U+AB65
PUA: Specials|U+F130..U+F133
PUA: Modifier letters (e.g. superscripts)|U+F1A1, U+F1A3..U+F1A4, U+F1AB, U+F1AE, U+F1B4..U+F1B5, U+F1BC, U+F1CD..U+F1CE, U+F1F1..U+F1F9
PUA: Latin|U+F20D, U+F234..U+F235, U+F258..U+F259, U+F267..U+F269, U+F26C..U+F26D
PUA: Cyrillic|U+F326..U+F327
Alphabetic Presentation Forms|U+FB00..U+FB04
Variation Selectors|U+FE00..U+FE0F
Combining Half Marks|U+FE20..U+FE23
Arabic Presentation Forms-B|U+FEFF (zero-width no-break space)
Specials|U+FFF9..U+FFFD
Latin Extended-F|U+10783, U+1078F, U+10791, U+10795, U+107A0, U+107A2..U+107A3, U+107B2
Nabatean|U+1088E
Mathematical Alphanumeric Symbols|U+1D40C, U+1D504..U+1D505, U+1D50A, U+1D50E..U+1D510, U+1D513..U+1D514, U+1D516..U+1D517, U+1D519
Latin Extended-G|U+1DF00..U+1DF1E
Enclosed Alphanumeric Supplement|U+1F12F

## Private-use (PUA) characters

There are a number of private-use characters that are supported in this font. These conform to [SIL International’s corporate registry](http://scripts.sil.org/PUA_home) for usage of the Unicode private-use areas. Characters which are not yet in Unicode are shown below. 

### Specials

- U+F130  FONT BASELINE AND SIDE-BEARING MARKER LEFT
- U+F131  FONT BASELINE AND SIDE-BEARING MARKER RIGHT
- U+F132  FONT VERTICAL METRICS MARKER LEFT
- U+F133  FONT VERTICAL METRICS MARKER RIGHT

### Modifier Letters

- U+F1CD  MODIFIER LETTER SMALL CAPITAL U BAR

### Latin

- U+F20D  LATIN CAPITAL LETTER D WITH STROKE AND HOOK
- U+F258  LATIN LETTER SMALL CAPITAL I OVER SMALL SCHWA
- U+F259  LATIN LETTER SMALL UPSILON OVER SMALL SCHWA
- U+F26D  LATIN SMALL LETTER B WITH LEFT HOOK
- U+F26E  LATIN CAPITAL LETTER RAMS HORN

### Cyrillic

- U+F326  CYRILLIC CAPITAL LETTER GHE WITH STROKE AND DESCENDER
- U+F327  CYRILLIC SMALL LETTER GHE WITH STROKE AND DESCENDER

### Deprecated SIL Corporate PUA characters

Some characters formerly in the PUA have been added to Unicode, and so have been deprecated in our fonts. Those PUA characters are displayed as black boxes containing a white image of the deprecated glyph.
